==> source-app-lab-0.2.0.zip: source-app-lab/ui-packages/images/assets/index.tsx <==
import AccountStarEmpty from './account-star-empty.svg?react';
import AccountStarFilled from './account-star-filled.svg?react';
import AccountViewFilled from './account-view-filled.svg?react';
import AccountViewFilledCrossed from './account-view-filled-crossed.svg?react';
import AddBrick from './add-brick.svg?react';
import AddTab from './add-tab.svg?react';
import Ai from './ai.svg?react';
import AppExamples from './app-examples.svg?react';
import AppLabBrickApi from './app-lab-brick-api.svg?react';
import AppLabBrickAudio from './app-lab-brick-audio.svg?react';
import AppLabBrickIot from './app-lab-brick-iot.svg?react';
import AppLabBrickMiscellaneous from './app-lab-brick-miscellaneous.svg?react';
import AppLabBrickStorage from './app-lab-brick-storage.svg?react';
import AppLabBrickText from './app-lab-brick-text.svg?react';
import AppLabBrickUi from './app-lab-brick-ui.svg?react';
import AppLabBrickVision from './app-lab-brick-vision.svg?react';
import AppLabCloudIot from './app-lab-cloud-iot.svg?react';
import AppLabFingerprint from './app-lab-fingerprint.svg?react';
import AppLabStatistics from './app-lab-statistics.svg?react';
import AppLabView from './app-lab-view.svg?react';
import AppLabWaveForm from './app-lab-waveform.svg?react';
import AppSettings from './app-settings.svg?react';
import Appearance from './appearance.svg?react';
import Apply from './apply.svg?react';
import ApplyFix from './apply-fix.svg?react';
import Archive from './archive.svg?react';
import ArduinoAssistant from './arduino-assistant.svg?react';
import ArduinoLoader from './arduino-loader.svg?react';
import ArduinoLogo from './arduino-logo.svg?react';
import ArduinoLoop from './arduino-loop.svg?react';
import ArrowDown from './arrow-down.svg?react';
import ArrowRight from './arrow-right.svg?react';
import ArrowRoundedUp from './arrow-rounded-up.svg?react';
import ArrowSquaredLeft from './arrow-squared-left.svg?react';
import ArrowSquaredUp from './arrow-squared-up.svg?react';
import AskIcon from './ask-icon.svg?react';
import AttentionExclamation from './attention-exclamation-icon.svg?react';
import BackArrow from './back-arrow.svg?react';
import BeResponsibleIcon from './be-responsible-icon.svg?react';
import Bin from './bin.svg?react';
import Board from './board.svg?react';
import BrickSettings from './brick-settings.svg?react';
import Bricks from './bricks.svg?react';
import CaretDown from './caret-down.svg?react';
import CaseSensitive from './case-sensitive.svg?react';
import ChatSend from './chat-send.svg?react';
import ChatStop from './chat-stop.svg?react';
import Checkbox from './checkbox.svg?react';
import Checkmark from './checkmark.svg?react';
import ChevronDown from './chevron-down.svg?react';
import ChevronRight from './chevron-right.svg?react';
import ChevronRightNoPad from './chevron-right-no-pad.svg?react';
import ChevronUp from './chevron-up.svg?react';
import Clear from './clear.svg?react';
import Close from './close.svg?react';
import CloseX from './close-x.svg?react';
import CloudEditorTitle from './cloud-editor-title.svg?react';
import CloudPortIcon from './cloud-port-icon.svg?react';
import CloudPortOff from './cloud-port-off.svg?react';
import CodeIcon from './code-icon.svg?react';
import ConnectionLostIcon from './connection-lost-icon.svg?react';
import Copy from './copy.svg?react';
import DarkTheme from './dark-theme.svg?react';
import Decrement from './decrement.svg?react';
import Device from './device.svg?react';
import DeviceAssociationConnect from './device-association-connect.svg?react';
import Dots from './dots.svg?react';
import Download from './download.svg?react';
import Duplicate from './duplicate.svg?react';
import EducationIcon from './education-icon.svg?react';
import Eraser from './eraser.svg?react';
import EraserIcon from './eraser-icon.svg?react';
import ExplainError from './explain-error.svg?react';
import FeedbackThumbsDown from './feedback-thumbs-down.svg?react';
import FeedbackThumbsUp from './feedback-thumbs-up.svg?react';
import FileAdd from './file-add.svg?react';
import FileConfig from './file-config.svg?react';
import FileCopy from './file-copy.svg?react';
import FileFolder from './file-folder.svg?react';
import FileFolderOpen from './file-folder-open.svg?react';
import FileGeneric from './file-generic.svg?react';
import FileIno from './file-ino.svg?react';
import FilePython from './file-python.svg?react';
import FileText from './file-text.svg?react';
import FileTypeHeader from './file-type-header.svg?react';
import FileTypeImage from './file-type-image.svg?react';
import FileTypeIno from './file-type-ino.svg?react';
import FileTypeSecrets from './file-type-secrets.svg?react';
import FileTypeText from './file-type-text.svg?react';
import FixError from './fix-error.svg?react';
import Folder from './folder.svg?react';
import FullScreenExpand from './fullscreen-expand-arrows.svg?react';
import GenAISendArrow from './gen-ai-send-arrow.svg?react';
import GoToError from './go-to-error.svg?react';
import GoogleClassroom from './google-classroom.svg?react';
import genAiBanner from './images/gen-ai-banner.png';
import genAiBannerBg from './images/gen-ai-banner-bg.png';
import userAvatar from './images/user-avatar.png';
import Increment from './increment.svg?react';
import IndentCode from './indent-code.svg?react';
import InfoIconI from './info-icon-i.svg?react';
import InfoIconOutline from './info-icon-outline.svg?react';
import Learn from './learn.svg?react';
import LibraryIcon from './library-icon.svg?react';
import LightIcon from './light-icon.svg?react';
import LightTheme from './light-theme.svg?react';
import LinkIcon from './link.svg?react';
import LinkIconDiagonal from './link-icon-diagonal.svg?react';
import Loader from './loader.svg?react';
import Login from './login.svg?react';
import ManualSelectBoard from './manual-select-board-icon.svg?react';
import MediaLibraryBooksNormal from './media-library_books-normal.svg?react';
import Models from './models.svg?react';
import Monitor from './monitor.svg?react';
import MyApps from './my-apps.svg?react';
import NavigationGroup from './navigation-group.svg?react';
import NoResults from './no-results.svg?react';
import NotFoundIconX from './not-found-icon-x.svg?react';
import NotFoundPageImage from './not-found-page-image.svg?react';
import NotificationSuccessCheck from './notification-success-check.svg?react';
import OnboardingBack from './onboarding-back.svg?react';
import OnboardingNext from './onboarding-next.svg?react';
import OpenInNewTab from './open-in-new-tab.svg?react';
import OperationListOutline from './operation-list-outline.svg?react';
import Palette from './palette.svg?react';
import Pause from './pause.svg?react';
import Pencil from './pencil.svg?react';
import PlayOutline from './play-outline.svg?react';
import PluginCables from './plugin-cables.svg?react';
import Plus from './plus.svg?react';
import PrivateDataIcon from './private-data-icon.svg?react';
import Puzzle from './puzzle.svg?react';
import Redo from './redo-icon.svg?react';
import RegularExpression from './regular-expression.svg?react';
import Reset from './reset.svg?react';
import Resource from './resource-icon.svg?react';
import ArduinoRoundLogo from './round-arduino-logo.svg?react';
import Run from './run.svg?react';
import Search from './search.svg?react';
import SearchClearX from './search-clear-x.svg?react';
import SearchMagnify from './search-magnify.svg?react';
import SelectArrow from './select-arrow.svg?react';
import SelectedDeviceTick from './selected-device-tick.svg?react';
import Settings from './settings.svg?react';
import ShareSketchIcon from './share-sketch-icon.svg?react';
import SidePanelTrigger from './side-panel-trigger.svg?react';
import Sketch from './sketch.svg?react';
import SketchIcon from './sketch-icon.svg?react';
import Sources from './sources.svg?react';
import Sparkle from './sparkle.svg?react';
import Speaker from './speaker.svg?react';
import Spinner from './spinner.svg?react';
import StatusError from './status-error.svg?react';
import StopWatch from './stopwatch.svg?react';
import StopWatchDisable from './stopwatch-disable.svg?react';
import SubtractMinus from './subtract-minus.svg?react';
import TechReference from './tech-reference.svg?react';
import Terminal from './terminal.svg?react';
import Text from './text.svg?react';
import ThreeDots from './three-dots.svg?react';
import ToggleOff from './toggle-off.svg?react';
import ToggleOn from './toggle-on.svg?react';
import ToolbarCancelX from './toolbar-cancel-x.svg?react';
import TravelCompassNormal from './travel-compass-normal.svg?react';
import Triangle from './triangle.svg?react';
import TriangleSharp from './triangle-sharp.svg?react';
import TriangleSharpOutline from './triangle-sharp-outline.svg?react';
import Undo from './undo-icon.svg?react';
import Unlink from './unlink-icon.svg?react';
import UnsavedBadge from './unsaved-badge.svg?react';
import Upload from './upload.svg?react';
import UploadClock from './upload-clock.svg?react';
import UploadLight from './upload-light.svg?react';
import UsbPort from './usb-port.svg?react';
import UserCommunity from './user-community.svg?react';
import Verify from './verify.svg?react';
import VerifyAndUpload from './verify-and-upload.svg?react';
import WholeWords from './whole-words.svg?react';

const Icons = {
  AccountStarEmpty,
  AccountStarFilled,
  AccountViewFilled,
  AccountViewFilledCrossed,
  AddBrick,
  AddTab,
  Ai,
  Appearance,
  AppExamples,
  AppLabBrickApi,
  AppLabBrickAudio,
  AppLabBrickIot,
  AppLabBrickMiscellaneous,
  AppLabBrickStorage,
  AppLabBrickText,
  AppLabBrickUi,
  AppLabBrickVision,
  AppLabCloudIot,
  AppLabFingerprint,
  AppLabStatistics,
  AppLabView,
  AppLabWaveForm,
  Apply,
  ApplyFix,
  AppSettings,
  Archive,
  ArduinoAssistant,
  ArduinoLoader,
  ArduinoLogo,
  ArduinoLoop,
  ArduinoRoundLogo,
  ArrowDown,
  ArrowRight,
  ArrowRoundedUp,
  ArrowSquaredLeft,
  ArrowSquaredUp,
  AskIcon,
  AttentionExclamation,
  BackArrow,
  BeResponsibleIcon,
  Bin,
  Board,
  BrickSettings,
  Bricks,
  CaretDown,
  CaseSensitive,
  ChatSend,
  ChatStop,
  Checkbox,
  Checkmark,
  ChevronDown,
  ChevronRight,
  ChevronRightNoPad,
  ChevronUp,
  Clear,
  Close,
  CloseX,
  CloudEditorTitle,
  CloudPortIcon,
  CloudPortOff,
  CodeIcon,
  ConnectionLostIcon,
  Copy,
  DarkTheme,
  Decrement,
  Device,
  DeviceAssociationConnect,
  Dots,
  Download,
  Duplicate,
  EducationIcon,
  Eraser,
  EraserIcon,
  ExplainError,
  FeedbackThumbsDown,
  FeedbackThumbsUp,
  FileAdd,
  FileIno,
  FileConfig,
  FileCopy,
  FileFolder,
  FileFolderOpen,
  FileGeneric,
  FilePython,
  FileText,
  FileTypeHeader,
  FileTypeImage,
  FileTypeIno,
  FileTypeSecrets,
  FileTypeText,
  FixError,
  Folder,
  FullScreenExpand,
  GenAISendArrow,
  GoogleClassroom,
  GoToError,
  Increment,
  IndentCode,
  InfoIconI,
  InfoIconOutline,
  Learn,
  LibraryIcon,
  LightIcon,
  LightTheme,
  LinkIcon,
  LinkIconDiagonal,
  Loader,
  ManualSelectBoard,
  MediaLibraryBooksNormal,
  Models,
  Monitor,
  MyApps,
  NavigationGroup,
  NoResults,
  NotFoundIconX,
  NotFoundPageImage,
  NotificationSuccessCheck,
  OnboardingBack,
  OnboardingNext,
  OpenInNewTab,
  OperationListOutline,
  Palette,
  Pause,
  Pencil,
  PlayOutline,
  PluginCables,
  Plus,
  PrivateDataIcon,
  Puzzle,
  Redo,
  RegularExpression,
  Reset,
  Resource,
  Run,
  Search,
  SearchClearX,
  SearchMagnify,
  SelectArrow,
  SelectedDeviceTick,
  Settings,
  ShareSketchIcon,
  SidePanelTrigger,
  Sketch,
  SketchIcon,
  Sources,
  Sparkle,
  Speaker,
  Spinner,
  StatusError,
  StopWatch,
  StopWatchDisable,
  SubtractMinus,
  TechReference,
  Terminal,
  Text,
  ThreeDots,
  ToggleOff,
  ToggleOn,
  ToolbarCancelX,
  TravelCompassNormal,
  Triangle,
  TriangleSharp,
  TriangleSharpOutline,
  Undo,
  Unlink,
  UnsavedBadge,
  Upload,
  UploadClock,
  UploadLight,
  UsbPort,
  UserCommunity,
  Verify,
  VerifyAndUpload,
  WholeWords,
  Login,
};

const Images = {
  userAvatar: <img src={userAvatar} alt="User avatar" width="52" height="52" />,
  genAiBanner: <img src={genAiBanner} alt="Gen AI Banner" />,
  genAiBannerBg: <img src={genAiBannerBg} alt="Gen AI Banner Background" />,
};

export { Icons, Images };

==> source-app-lab-0.3.1.zip: source-app-lab/ui-packages/images/assets/index.tsx <==
import AccountStarEmpty from './account-star-empty.svg?react';
import AccountStarFilled from './account-star-filled.svg?react';
import AccountViewFilled from './account-view-filled.svg?react';
import AccountViewFilledCrossed from './account-view-filled-crossed.svg?react';
import AddBrick from './add-brick.svg?react';
import AddTab from './add-tab.svg?react';
import Ai from './ai.svg?react';
import AppExamples from './app-examples.svg?react';
import AppLabBrickApi from './app-lab-brick-api.svg?react';
import AppLabBrickAudio from './app-lab-brick-audio.svg?react';
import AppLabBrickIot from './app-lab-brick-iot.svg?react';
import AppLabBrickMiscellaneous from './app-lab-brick-miscellaneous.svg?react';
import AppLabBrickStorage from './app-lab-brick-storage.svg?react';
import AppLabBrickText from './app-lab-brick-text.svg?react';
import AppLabBrickUi from './app-lab-brick-ui.svg?react';
import AppLabBrickVision from './app-lab-brick-vision.svg?react';
import AppLabCloudIot from './app-lab-cloud-iot.svg?react';
import AppLabFingerprint from './app-lab-fingerprint.svg?react';
import AppLabStatistics from './app-lab-statistics.svg?react';
import AppLabToggleOff from './app-lab-toggle-off.svg?react';
import AppLabToggleOn from './app-lab-toggle-on.svg?react';
import AppLabView from './app-lab-view.svg?react';
import AppLabWaveForm from './app-lab-waveform.svg?react';
import AppSettings from './app-settings.svg?react';
import Appearance from './appearance.svg?react';
import Apply from './apply.svg?react';
import ApplyFix from './apply-fix.svg?react';
import Archive from './archive.svg?react';
import ArduinoAssistant from './arduino-assistant.svg?react';
import ArduinoLoader from './arduino-loader.svg?react';
import ArduinoLogo from './arduino-logo.svg?react';
import ArduinoLoop from './arduino-loop.svg?react';
import ArrowDown from './arrow-down.svg?react';
import ArrowRight from './arrow-right.svg?react';
import ArrowRoundedUp from './arrow-rounded-up.svg?react';
import ArrowSquaredLeft from './arrow-squared-left.svg?react';
import ArrowSquaredUp from './arrow-squared-up.svg?react';
import AskIcon from './ask-icon.svg?react';
import AttentionExclamation from './attention-exclamation-icon.svg?react';
import BackArrow from './back-arrow.svg?react';
import BeResponsibleIcon from './be-responsible-icon.svg?react';
import Bell from './bell.svg?react';
import BellWithDot from './bell-with-dot.svg?react';
import Bin from './bin.svg?react';
import Board from './board.svg?react';
import BrickSettings from './brick-settings.svg?react';
import Bricks from './bricks.svg?react';
import CaretDown from './caret-down.svg?react';
import CaseSensitive from './case-sensitive.svg?react';
import ChatSend from './chat-send.svg?react';
import ChatStop from './chat-stop.svg?react';
import Checkbox from './checkbox.svg?react';
import Checkmark from './checkmark.svg?react';
import ChevronDown from './chevron-down.svg?react';
import ChevronRight from './chevron-right.svg?react';
import ChevronRightNoPad from './chevron-right-no-pad.svg?react';
import ChevronUp from './chevron-up.svg?react';
import Clear from './clear.svg?react';
import Close from './close.svg?react';
import CloseX from './close-x.svg?react';
import CloudEditorTitle from './cloud-editor-title.svg?react';
import CloudPortIcon from './cloud-port-icon.svg?react';
import CloudPortOff from './cloud-port-off.svg?react';
import CodeIcon from './code-icon.svg?react';
import ConnectionLostIcon from './connection-lost-icon.svg?react';
import Copy from './copy.svg?react';
import DarkTheme from './dark-theme.svg?react';
import Decrement from './decrement.svg?react';
import Device from './device.svg?react';
import DeviceAssociationConnect from './device-association-connect.svg?react';
import Dots from './dots.svg?react';
import Download from './download.svg?react';
import Duplicate from './duplicate.svg?react';
import EducationIcon from './education-icon.svg?react';
import Eraser from './eraser.svg?react';
import EraserIcon from './eraser-icon.svg?react';
import ExplainError from './explain-error.svg?react';
import FeedbackThumbsDown from './feedback-thumbs-down.svg?react';
import FeedbackThumbsUp from './feedback-thumbs-up.svg?react';
import FileAdd from './file-add.svg?react';
import FileConfig from './file-config.svg?react';
import FileCopy from './file-copy.svg?react';
import FileFolder from './file-folder.svg?react';
import FileFolderOpen from './file-folder-open.svg?react';
import FileGeneric from './file-generic.svg?react';
import FileHeader from './file-header.svg?react';
import FileImage from './file-image.svg?react';
import FileIno from './file-ino.svg?react';
import FilePython from './file-python.svg?react';
import FileText from './file-text.svg?react';
import FileTypeHeader from './file-type-header.svg?react';
import FileTypeImage from './file-type-image.svg?react';
import FileTypeIno from './file-type-ino.svg?react';
import FileTypeSecrets from './file-type-secrets.svg?react';
import FileTypeText from './file-type-text.svg?react';
import FixError from './fix-error.svg?react';
import Folder from './folder.svg?react';
import FolderAdd from './folder-add.svg?react';
import FullScreenExpand from './fullscreen-expand-arrows.svg?react';
import GenAISendArrow from './gen-ai-send-arrow.svg?react';
import GoToError from './go-to-error.svg?react';
import GoogleClassroom from './google-classroom.svg?react';
import genAiBanner from './images/gen-ai-banner.png';
import genAiBannerBg from './images/gen-ai-banner-bg.png';
import userAvatar from './images/user-avatar.png';
import Increment from './increment.svg?react';
import IndentCode from './indent-code.svg?react';
import InfoIconI from './info-icon-i.svg?react';
import InfoIconOutline from './info-icon-outline.svg?react';
import Learn from './learn.svg?react';
import LibraryIcon from './library-icon.svg?react';
import LightIcon from './light-icon.svg?react';
import LightTheme from './light-theme.svg?react';
import LinkIcon from './link.svg?react';
import LinkIconDiagonal from './link-icon-diagonal.svg?react';
import Loader from './loader.svg?react';
import Login from './login.svg?react';
import ManualSelectBoard from './manual-select-board-icon.svg?react';
import MediaLibraryBooksNormal from './media-library_books-normal.svg?react';
import Models from './models.svg?react';
import Monitor from './monitor.svg?react';
import MyApps from './my-apps.svg?react';
import NavigationGroup from './navigation-group.svg?react';
import NoResults from './no-results.svg?react';
import NotFoundIconX from './not-found-icon-x.svg?react';
import NotFoundPageImage from './not-found-page-image.svg?react';
import NotificationSuccessCheck from './notification-success-check.svg?react';
import OnboardingBack from './onboarding-back.svg?react';
import OnboardingNext from './onboarding-next.svg?react';
import OpenInNewTab from './open-in-new-tab.svg?react';
import OperationListOutline from './operation-list-outline.svg?react';
import Palette from './palette.svg?react';
import Pause from './pause.svg?react';
import Pencil from './pencil.svg?react';
import PlayOutline from './play-outline.svg?react';
import PluginCables from './plugin-cables.svg?react';
import Plus from './plus.svg?react';
import Power from './power.svg?react';
import PrivateDataIcon from './private-data-icon.svg?react';
import Puzzle from './puzzle.svg?react';
import Redo from './redo-icon.svg?react';
import RegularExpression from './regular-expression.svg?react';
import Reset from './reset.svg?react';
import Resource from './resource-icon.svg?react';
import ArduinoRoundLogo from './round-arduino-logo.svg?react';
import Run from './run.svg?react';
import Search from './search.svg?react';
import SearchClearX from './search-clear-x.svg?react';
import SearchMagnify from './search-magnify.svg?react';
import SelectArrow from './select-arrow.svg?react';
import SelectedDeviceTick from './selected-device-tick.svg?react';
import Settings from './settings.svg?react';
import ShareSketchIcon from './share-sketch-icon.svg?react';
import SidePanelTrigger from './side-panel-trigger.svg?react';
import Sketch from './sketch.svg?react';
import SketchIcon from './sketch-icon.svg?react';
import Sources from './sources.svg?react';
import Sparkle from './sparkle.svg?react';
import Speaker from './speaker.svg?react';
import Spinner from './spinner.svg?react';
import StatusError from './status-error.svg?react';
import StopWatch from './stopwatch.svg?react';
import StopWatchDisable from './stopwatch-disable.svg?react';
import SubtractMinus from './subtract-minus.svg?react';
import TechReference from './tech-reference.svg?react';
import Terminal from './terminal.svg?react';
import Text from './text.svg?react';
import ThreeDots from './three-dots.svg?react';
import ToggleOff from './toggle-off.svg?react';
import ToggleOn from './toggle-on.svg?react';
import ToolbarCancelX from './toolbar-cancel-x.svg?react';
import TravelCompassNormal from './travel-compass-normal.svg?react';
import Triangle from './triangle.svg?react';
import TriangleSharp from './triangle-sharp.svg?react';
import TriangleSharpOutline from './triangle-sharp-outline.svg?react';
import Undo from './undo-icon.svg?react';
import Unlink from './unlink-icon.svg?react';
import UnsavedBadge from './unsaved-badge.svg?react';
import Upload from './upload.svg?react';
import UploadClock from './upload-clock.svg?react';
import UploadLight from './upload-light.svg?react';
import UsbPort from './usb-port.svg?react';
import UserCommunity from './user-community.svg?react';
import Verify from './verify.svg?react';
import VerifyAndUpload from './verify-and-upload.svg?react';
import WholeWords from './whole-words.svg?react';

const Icons = {
  AccountStarEmpty,
  AccountStarFilled,
  AccountViewFilled,
  AccountViewFilledCrossed,
  AddBrick,
  AddTab,
  Ai,
  Appearance,
  AppExamples,
  AppLabBrickApi,
  AppLabBrickAudio,
  AppLabBrickIot,
  AppLabBrickMiscellaneous,
  AppLabBrickStorage,
  AppLabBrickText,
  AppLabBrickUi,
  AppLabBrickVision,
  AppLabCloudIot,
  AppLabFingerprint,
  AppLabStatistics,
  AppLabToggleOff,
  AppLabToggleOn,
  AppLabView,
  AppLabWaveForm,
  Apply,
  ApplyFix,
  AppSettings,
  Archive,
  ArduinoAssistant,
  ArduinoLoader,
  ArduinoLogo,
  ArduinoLoop,
  ArduinoRoundLogo,
  ArrowDown,
  ArrowRight,
  ArrowRoundedUp,
  ArrowSquaredLeft,
  ArrowSquaredUp,
  AskIcon,
  AttentionExclamation,
  BackArrow,
  Bell,
  BellWithDot,
  BeResponsibleIcon,
  Bin,
  Board,
  BrickSettings,
  Bricks,
  CaretDown,
  CaseSensitive,
  ChatSend,
  ChatStop,
  Checkbox,
  Checkmark,
  ChevronDown,
  ChevronRight,
  ChevronRightNoPad,
  ChevronUp,
  Clear,
  Close,
  CloseX,
  CloudEditorTitle,
  CloudPortIcon,
  CloudPortOff,
  CodeIcon,
  ConnectionLostIcon,
  Copy,
  DarkTheme,
  Decrement,
  Device,
  DeviceAssociationConnect,
  Dots,
  Download,
  Duplicate,
  EducationIcon,
  Eraser,
  EraserIcon,
  ExplainError,
  FeedbackThumbsDown,
  FeedbackThumbsUp,
  FileAdd,
  FileIno,
  FileConfig,
  FileCopy,
  FileFolder,
  FileFolderOpen,
  FileGeneric,
  FileHeader,
  FileImage,
  FilePython,
  FileText,
  FileTypeHeader,
  FileTypeImage,
  FileTypeIno,
  FileTypeSecrets,
  FileTypeText,
  FixError,
  Folder,
  FolderAdd,
  FullScreenExpand,
  GenAISendArrow,
  GoogleClassroom,
  GoToError,
  Increment,
  IndentCode,
  InfoIconI,
  InfoIconOutline,
  Learn,
  LibraryIcon,
  LightIcon,
  LightTheme,
  LinkIcon,
  LinkIconDiagonal,
  Loader,
  ManualSelectBoard,
  MediaLibraryBooksNormal,
  Models,
  Monitor,
  MyApps,
  NavigationGroup,
  NoResults,
  NotFoundIconX,
  NotFoundPageImage,
  NotificationSuccessCheck,
  OnboardingBack,
  OnboardingNext,
  OpenInNewTab,
  OperationListOutline,
  Palette,
  Pause,
  Pencil,
  PlayOutline,
  PluginCables,
  Plus,
  Power,
  PrivateDataIcon,
  Puzzle,
  Redo,
  RegularExpression,
  Reset,
  Resource,
  Run,
  Search,
  SearchClearX,
  SearchMagnify,
  SelectArrow,
  SelectedDeviceTick,
  Settings,
  ShareSketchIcon,
  SidePanelTrigger,
  Sketch,
  SketchIcon,
  Sources,
  Sparkle,
  Speaker,
  Spinner,
  StatusError,
  StopWatch,
  StopWatchDisable,
  SubtractMinus,
  TechReference,
  Terminal,
  Text,
  ThreeDots,
  ToggleOff,
  ToggleOn,
  ToolbarCancelX,
  TravelCompassNormal,
  Triangle,
  TriangleSharp,
  TriangleSharpOutline,
  Undo,
  Unlink,
  UnsavedBadge,
  Upload,
  UploadClock,
  UploadLight,
  UsbPort,
  UserCommunity,
  Verify,
  VerifyAndUpload,
  WholeWords,
  Login,
};

const Images = {
  userAvatar: <img src={userAvatar} alt="User avatar" width="52" height="52" />,
  genAiBanner: <img src={genAiBanner} alt="Gen AI Banner" />,
  genAiBannerBg: <img src={genAiBannerBg} alt="Gen AI Banner Background" />,
};

export { Icons, Images };
